pub fn to_string_pythonic<T>(value: &T) -> Result<String>Available on crate feature
std only.Expand description
Serialize the given data structure as a String of Pythonic JSON representation.
Errors
Serialization can fail if T’s implementation of Serialize decides to
fail, or if T contains a map with non-string keys.